@@ -1,12 +1,22 @@
 from __future__ import annotations
-from pymint.mintparams import MINTParams
+
+from typing import TYPE_CHECKING, List
+
 from parchmint.connection import Connection
+
+if TYPE_CHECKING:
+    from pymint import MINTLayer
+
+from pymint.mintparams import MINTParams
 from pymint.minttarget import MINTTarget
-from typing import List
-from pymint import MINTLayer
 
 
 class MINTConnection(Connection):
+    """Connection class abstracting parchmint Connection class that adding
+    helper methods to generate MINT
+
+    """
+
     def __init__(
         self,
         name: str,
